@@ -1,13 +1,14 @@
 /*
-    SPDX-FileCopyrightText: 2012-2020 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2012-2022 Harald Sitter <sitter@kde.org>
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "Entry.h"
 
-Entry::Entry(const KLocalizedString &label_, const QString &value_)
+Entry::Entry(const KLocalizedString &label_, const QString &value_, Hidden hidden)
     : m_label(label_)
     , m_value(value_)
+    , m_hidden(hidden)
 {
     Q_ASSERT(m_label.isEmpty() || localizedLabel(Language::English).endsWith(':'));
 }
@@ -57,6 +58,11 @@ QString Entry::localizedValue(Language language) const
     return m_value;
 }
 
+bool Entry::isHidden() const
+{
+    return m_hidden == Hidden::Yes;
+}
+
 QLocale Entry::localeForLanguage(Language language) const
 {
     switch (language) {
@@ -68,3 +74,5 @@ QLocale Entry::localeForLanguage(Language language) const
     Q_UNREACHABLE();
     return QLocale::system();
 }
+
+#include "moc_Entry.cpp"
