@@ -4,28 +4,22 @@
     SPDX-FileCopyrightText: 2022 Tobias C. Berner <tcberner@FreeBSD.org>
 */
 
-#include <KAboutData>
-#include <KLocalizedString>
 #include <KPluginFactory>
-#include <KQuickAddons/ConfigModule>
+#include <KQuickConfigModule>
 
 #include <CommandOutputContext.h>
 
 #include "backend.h"
 
-class KCMXServer : public KQuickAddons::ConfigModule
+class KCMXServer : public KQuickConfigModule
 {
     Q_OBJECT
 public:
-    explicit KCMXServer(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-        : ConfigModule(parent, data, args)
+    explicit KCMXServer(QObject *parent, const KPluginMetaData &data)
+        : KQuickConfigModule(parent, data)
     {
         auto outputContext = new CommandOutputContext(QStringLiteral(PCI_BACKEND), {QStringLiteral(PCI_BACKEND_ARGUMENTS)}, parent);
         qmlRegisterSingletonInstance("org.kde.kinfocenter.pci.private", 1, 0, "InfoOutputContext", outputContext);
-
-        auto *about = new KAboutData(QStringLiteral("kcm_pci"), i18nc("@label kcm name", "PCI"), QStringLiteral("1.0"), QString(), KAboutLicense::GPL);
-        about->addAuthor(i18n("Harald Sitter"), QString(), QStringLiteral("sitter@kde.org"));
-        setAboutData(about);
     }
 };
 
